
%               _       _   _ 
%    __  _____ | | ___ | |_| |
%    \ \/ / _ \| |/ _ \| __| |
%     >  < (_) | | (_) | |_| |
%    /_/\_\___/|_|\___/ \__|_|
%
% ### filterOutputData
%
%
% **Syntax**
%
% ```matlab
% matrix = xolotl.filterOutputData(data,*keyword)
% matrix = xolotl.filterOutputData(data,exact_name)
% ```
%
% **Description**
%
% This function filters the output structure generated by
% integration when x.output_mode = 1
% allowing you to easily isolate groups of outputs
% that you might be interested in
%
% See Also: 
% xolotl.integrate
%

function data = filterOutputData(S, key)

arguments
	S (1,1) struct
	key char 
end

fn = fieldnames(S);

data = [];


if any(strfind(key,'*'))
	wkey = strrep(key,'*','');
else
	wkey = '';
end

for i = 1:length(fn)
	temp = S.(fn{i});
	if isstruct(temp)
		new_data = xolotl.filterOutputData(temp,key);
		if isempty(data)
			data = new_data;
		else
			data = [data new_data];
		end
	else
		if ~isempty(strfind(fn{i},wkey)) | strcmp(fn{i},key)
			% key match

			if isempty(data)
				data = temp;
			else
				data = [data temp];
			end
		end
	end
end