function finalCurrentInj = makeCurrent_Channels_Xolotl(simDurSec,timeStep, exciteCurrentAmp, inhibCurrentAmp, numExcitatoryChannels, numInhibitoryChannels, numOpeningsPerChan, currentDurationSec, xolotolTimeStep) 

%%
% ccc
% save('/home/mark/matlab_temp_variables/currinj') ;
% load('/home/mark/matlab_temp_variables/currinj')  ;
% 
% numInhibitoryChannels = 3


%% create time vector for simulation
timeVecSim = (0:(timeStep/1000): simDurSec-(timeStep/1000))' ;

%% make noisy place holder for current injection vector
currInj = 0.01*randn(length(timeVecSim),1);
allCurrInj = currInj ;

%% make inhibitory currents
if numInhibitoryChannels > 0
    %% create waitbar
        f = waitbar(0, 'Inserting Inhibitory Channels') ;
    %% loop through number of channels
    for iChan = 1:numInhibitoryChannels
        %% create channel openings
        channelOpenings = generateRandomChannelOpenings(simDurSec, numOpeningsPerChan, currentDurationSec) ;

        %% insert openings
        currInj = insertXolotlChannels(currInj, channelOpenings, timeVecSim, inhibCurrentAmp) ;

        %% update the simulation's final current injection (allCurrInj)
        allCurrInj = allCurrInj + currInj ;

        %% force the simulation to include simultaneous openings of multiple channels
        if iChan > 1 && iChan < 5 
            theMaxCurrent = abs(min(allCurrInj)) ;
            targetCurrent = iChan * abs(inhibCurrentAmp) ;
            while theMaxCurrent < targetCurrent
                channelOpenings = generateRandomChannelOpenings(simDurSec, numOpeningsPerChan, currentDurationSec) ;
                currInj = zeros(length(timeVecSim),1) ;
                currInj = insertXolotlChannels(currInj, channelOpenings, timeVecSim, inhibCurrentAmp) ;
                clear channelOpenings
                allCurrInj = allCurrInj + currInj ;
                theMaxCurrent = abs(min(allCurrInj)) ;
            end
        end

        %% clear out current channel's openings
        currInj = zeros(length(timeVecSim),1) ;

        % update progress bar
        waitbar(iChan/numInhibitoryChannels, f, 'Inserting Inhibitory Channels')

        clear channelOpenings
    end
     %% close waitbar
    close(f)
end

%% make excitatory currents
if numExcitatoryChannels > 0
     %% create waitbar
        f = waitbar(0, 'Inserting Excitatory Channels') ;
    %% loop through number of channels
    for iChan = 1:numExcitatoryChannels
       %% create channel openings
        channelOpenings = generateRandomChannelOpenings(simDurSec, numOpeningsPerChan, currentDurationSec) ;

        %% insert openings
        currInj = insertXolotlChannels(currInj, channelOpenings, timeVecSim, exciteCurrentAmp) ;

        %% update the simulation's final current injection (allCurrInj)
        allCurrInj = allCurrInj + currInj ;

        %% force the simulation to include simultaneous openings of multiple channels
        if iChan > 1 && iChan < 5 
            theMaxCurrent = abs(max(allCurrInj)) ;
            targetCurrent = iChan * abs(exciteCurrentAmp) ;
            while theMaxCurrent < targetCurrent
                channelOpenings = generateRandomChannelOpenings(simDurSec, numOpeningsPerChan, currentDurationSec) ;
                currInj = zeros(length(timeVecSim),1) ;
                currInj = insertXolotlChannels(currInj, channelOpenings, timeVecSim, exciteCurrentAmp) ;
                clear channelOpenings
                allCurrInj = allCurrInj + currInj ;
                theMaxCurrent = abs(max(allCurrInj)) ;
            end
        end

        %% clear out current channel's openings
        currInj = zeros(length(timeVecSim),1) ;


        % update progress bar
        waitbar(iChan/numExcitatoryChannels, f, 'Inserting Excitatory Channels')

        clear channelOpenings
    end
    %% close waitbar
    close(f)
end



%% decimate current injection to conform to default xolotl timestep
decimateVal = xolotolTimeStep/timeStep ;
finalCurrentInj = downsample(allCurrInj, decimateVal) ;
finalTimeVecSim = (0:xolotolTimeStep/1000: simDurSec-(xolotolTimeStep/1000))' ;



%% plot
% subplot(2,1,1)
%     plot(timeVecSim, allCurrInj)
%     axis([0 simDurSec min(allCurrInj)*1.2 max(allCurrInj)*1.2])
% 
% subplot(2,1,2)
%     plot(finalTimeVecSim, finalCurrentInj)
%     axis([0 simDurSec min(finalCurrentInj)*1.2 max(finalCurrentInj)*1.2])

% 







